@@ -18,12 +18,12 @@
 #'
 #' @examplesIf require("lme4", quietly = TRUE)
 #' library(ggeffects)
-#' data(efc)
+#' data(efc, package = "ggeffects")
 #' efc$e15relat <- as.factor(efc$e15relat)
 #' efc$c161sex <- as.factor(efc$c161sex)
 #' levels(efc$c161sex) <- c("male", "female")
 #' model <- lme4::lmer(neg_c_7 ~ c161sex + (1 | e15relat), data = efc)
-#' me <- ggpredict(model, terms = "c161sex")
+#' me <- predict_response(model, terms = "c161sex")
 #' head(attributes(me)$rawdata)
 #' collapse_by_group(me, model, "e15relat")
 #' @export
@@ -32,7 +32,7 @@ collapse_by_group <- function(grid, model, collapse_by = NULL, residuals = FALSE
     insight::format_error("This function only works with mixed effects models.")
   }
 
-  model_data <- insight::get_data(model, source = "frame")
+  model_data <- insight::get_data(model, source = "frame", verbose = FALSE)
 
   if (is.null(collapse_by)) {
     collapse_by <- insight::find_random(model, flatten = TRUE)
@@ -57,6 +57,9 @@ collapse_by_group <- function(grid, model, collapse_by = NULL, residuals = FALSE
     rawdata <- attr(grid, "rawdata", exact = TRUE)
     y_name <- "response"
 
+    # we need this column for labelling data points, but not for collapsing
+    rawdata$rowname <- NULL
+
     if (any(vapply(rawdata[-(1:2)], Negate(is.factor), logical(1))) || attr(grid, "x.is.factor", exact = TRUE) == "0") { # nolint
       insight::format_alert("Collapsing usually not informative across a continuous variable.")
     }
