@@ -1,10 +1,25 @@
-get_predictions_clm <- function(model, data_grid, ci.lvl, linv, ...) {
+#' @export
+get_predictions.clm <- function(model,
+                                data_grid = NULL,
+                                terms = NULL,
+                                ci_level = 0.95,
+                                type = NULL,
+                                typical = NULL,
+                                vcov = NULL,
+                                vcov_args = NULL,
+                                condition = NULL,
+                                interval = "confidence",
+                                bias_correction = FALSE,
+                                link_inverse = insight::link_inverse(model),
+                                model_info = NULL,
+                                verbose = TRUE,
+                                ...) {
   # does user want standard errors?
-  se <- !is.null(ci.lvl) && !is.na(ci.lvl)
+  se <- !is.null(ci_level) && !is.na(ci_level)
 
   # compute ci, two-ways
-  if (!is.null(ci.lvl) && !is.na(ci.lvl)) {
-    ci <- ci.lvl
+  if (!is.null(ci_level) && !is.na(ci_level)) {
+    ci <- ci_level
   } else {
     ci <- 0.95
   }
@@ -26,7 +41,7 @@ get_predictions_clm <- function(model, data_grid, ci.lvl, linv, ...) {
   data_grid <- cbind(prdat, data_grid)
 
   # get levels of response
-  lv <- levels(insight::get_response(model))
+  lv <- levels(insight::get_response(model, verbose = FALSE))
 
   # for proportional ordinal logistic regression (see ordinal::clm),
   # we have predicted values for each response category. Hence,
