@@ -1,9 +1,12 @@
 #' @rdname ggpredict
 #' @export
-ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_level, ...) {
+ggeffect <- function(model, terms, ci_level = 0.95, bias_correction = FALSE, verbose = TRUE, ...) {
   insight::check_if_installed("effects")
   model_name <- deparse(substitute(model))
 
+  # check formula
+  insight::formula_ok(model, verbose = verbose)
+
   # process "terms", so we have the default character format. Furthermore,
   # check terms argument, to make sure that terms were not misspelled and are
   # indeed existing in the data
@@ -11,49 +14,41 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
     terms <- .reconstruct_focal_terms(terms, model)
   }
 
-  ## TODO: add warnings later
-
-  # handle deprectated arguments
-  if (!missing(ci.lvl)) {
-    ci_level <- ci.lvl
-  }
-
   # tidymodels?
   if (inherits(model, "model_fit")) {
     model <- model$fit
   }
 
-  if (inherits(model, "list")  && !inherits(model, c("bamlss", "maxLik"))) {
-    res <- lapply(model, .ggeffect_helper, terms, ci.lvl = ci_level, verbose, ...)
-  } else {
-    if (missing(terms) || is.null(terms)) {
-      predictors <- insight::find_predictors(
-        model,
-        effects = "fixed",
-        component = "conditional",
-        flatten = TRUE
-      )
-      res <- lapply(
-        predictors,
-        function(.x) {
-          tmp <- .ggeffect_helper(model, terms = .x, ci.lvl = ci_level, verbose, ...)
-          if (!is.null(tmp)) {
-            tmp$group <- .x
-          }
-          tmp
+  if (inherits(model, "list") && !inherits(model, c("bamlss", "maxLik"))) {
+    res <- lapply(model, .ggeffect_helper, terms, ci_level = ci_level, bias_correction = bias_correction, verbose, ...)
+  } else if (missing(terms) || is.null(terms)) {
+    predictors <- insight::find_predictors(
+      model,
+      effects = "fixed",
+      component = "conditional",
+      flatten = TRUE,
+      verbose = FALSE
+    )
+    res <- lapply(
+      predictors,
+      function(.x) {
+        tmp <- .ggeffect_helper(model, terms = .x, ci_level = ci_level, bias_correction = bias_correction, verbose, ...)
+        if (!is.null(tmp)) {
+          tmp$group <- .x
         }
-      )
-      no_results <- vapply(res, is.null, logical(1))
-      res <- .compact_list(res)
-      if (!is.null(res) && !.is_empty(res)) {
-        names(res) <- predictors[!no_results]
-        class(res) <- c("ggalleffects", class(res))
-      } else {
-        res <- NULL
+        tmp
       }
+    )
+    no_results <- vapply(res, is.null, logical(1))
+    res <- .compact_list(res)
+    if (!is.null(res) && !.is_empty(res)) {
+      names(res) <- predictors[!no_results]
+      class(res) <- c("ggalleffects", class(res))
     } else {
-      res <- .ggeffect_helper(model, terms, ci.lvl = ci_level, verbose, ...)
+      res <- NULL
     }
+  } else {
+    res <- .ggeffect_helper(model, terms, ci_level = ci_level, bias_correction = bias_correction, verbose, ...)
   }
 
   if (!is.null(res)) {
@@ -63,7 +58,12 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
 }
 
 
-.ggeffect_helper <- function(model, terms, ci.lvl, verbose = TRUE, ...) {
+.ggeffect_helper <- function(model,
+                             terms,
+                             ci_level,
+                             bias_correction = FALSE,
+                             verbose = TRUE,
+                             ...) {
   # check terms argument
   original_terms <- terms
 
@@ -76,11 +76,29 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
   # get model family and information
   model_info <- .get_model_info(model)
 
+  # additional arguments
+  additional_dot_args <- list(...)
+
+  # check valid additional arguments
+  .validate_dot_arguments(
+    additional_dot_args,
+    not_allowed = c(
+      "type", "typical", "condition", "back_transform", "vcov",
+      "vcov_args", "weights"
+    ),
+    fun = "ggeffect()"
+  )
+
+  # check if bias-correction is appropriate
+  bias_correction <- .check_bias_correction(
+    model,
+    type = "fixed",
+    bias_correction = bias_correction,
+    verbose = verbose
+  )
+
   # check whether we have an argument "transformation" for effects()-function
-  # in this case, we need another default title, since we have
-  # non-transformed effects
-  additional_dot_args <- match.call(expand.dots = FALSE)[["..."]]
-  # check whether we have a "transformation" argument
+  # in this case, we need another default title, since we have non-transformed effects
   t.add <- which(names(additional_dot_args) == "transformation")
   # if we have a "transformation" argument, and it's NULL,
   # no transformation of scale
@@ -112,22 +130,20 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
   # restore inital order of focal predictors
   at_values <- at_values[match(terms, names(at_values))]
 
-  # compute marginal effects for each model term
+  # compute adjusted predictions for each model term
   eff <- tryCatch(
-    {
-      suppressMessages(suppressWarnings(
-        effects::Effect(
-          focal.predictors = terms,
-          mod = model,
-          xlevels = at_values,
-          confidence.level = ci.lvl,
-          ...
-        )
-      ))
-    },
+    suppressMessages(suppressWarnings(
+      effects::Effect(
+        focal.predictors = terms,
+        mod = model,
+        xlevels = at_values,
+        confidence.level = ci_level,
+        ...
+      )
+    )),
     error = function(e) {
       if (verbose) {
-        insight::print_color("Can't compute marginal effects, `effects::Effect()` returned an error.\n\n", "red")
+        insight::print_color("Can't compute adjusted predictions, `effects::Effect()` returned an error.\n\n", "red")
         cat(sprintf("Reason: %s\n", e$message))
         cat("You may try `ggpredict()` or `ggemmeans()`.\n\n")
       }
@@ -143,57 +159,20 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
   # build data frame, with raw values
   # predicted response and lower/upper ci
 
+  dof <- .get_df(model)
+
   if (inherits(model, c("polr", "clm", "clm2", "clmm", "clmm2", "multinom", "nestedLogit"))) {
-
-    # for categorical outcomes, we need to gather the data
-    # from effects to get a single data frame
-
-    eff.logits <- as.data.frame(eff$logit, stringsAsFactors = FALSE)
-    tmp <- cbind(eff$x, eff.logits)
-    ft <- (ncol(tmp) - ncol(eff.logits) + 1):ncol(tmp)
-    tmp <- .gather(
-      tmp,
-      names_to = "response.level",
-      values_to = "predicted",
-      colnames(tmp)[ft]
-    )
-
-    fx.term <- eff$term
-
-    colnames(tmp)[1] <- "x"
-    if (length(terms) > 1) colnames(tmp)[2] <- "group"
-    if (length(terms) > 2) colnames(tmp)[3] <- "facet"
-
-    if (!is.null(ci.lvl) && !is.na(ci.lvl)) {
-      ci <- 1 - ((1 - ci.lvl) / 2)
+    # if predictions on the latent scale are requested, different handling here
+    if (isTRUE(additional_dot_args$latent)) {
+      tmp <- .effect_latent_predictions(eff, model, terms, ci_level, dof)
+      no.transform <- TRUE
     } else {
-      ci <- 0.975
-    }
-
-    # degrees of freedom
-    dof <- .get_df(model)
-    tcrit <- stats::qt(ci, df = dof)
-
-    # same for standard errors. we need to gather all data frames together,
-    # compute CI manually and then also fix column names.
-
-    eff.se.logits <- as.data.frame(eff$se.logit)
-    tmp2 <- .gather(
-      eff.se.logits,
-      names_to = "response.level",
-      values_to = "se",
-      colnames(eff.se.logits)
-    )
-    tmp2$conf.low <- tmp$predicted - tcrit * tmp2$se
-    tmp2$conf.high <- tmp$predicted + tcrit * tmp2$se
-    tmp2$std.error <- tmp2$se
-
-    tmp <- cbind(tmp, tmp2[, c("std.error", "conf.low", "conf.high")])
-    if (!inherits(model, "nestedLogit")) {
-      tmp$response.level <- substr(tmp$response.level, 7, max(nchar(tmp$response.level)))
+      # for categorical outcomes, we need to gather the data
+      # from effects to get a single data frame, unless we have latent = TRUE
+      tmp <- .effect_prob_predictions(eff, model, terms, ci_level, dof)
     }
+    fx.term <- eff$term
   } else {
-
     # check for multi response
 
     .ne <- names(eff)
@@ -239,7 +218,7 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
 
 
   if (!no.transform) {
-    linv <- insight::link_inverse(model)
+    linv <- .link_inverse(model, bias_correction = bias_correction, ...)
     tmp$predicted <- linv(tmp$predicted)
     tmp$conf.low <- linv(tmp$conf.low)
     tmp$conf.high <- linv(tmp$conf.high)
@@ -318,7 +297,6 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
   # add raw data as well
   attr(result, "rawdata") <- .get_raw_data(model, original_model_frame, terms)
 
-
   x_v <- original_model_frame[[fx.term]]
   if (is.null(x_v)) {
     xif <- ifelse(is.factor(tmp$x), "1", "0")
@@ -340,8 +318,12 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
     x.axis.labels = all.labels$axis.labels,
     model_info = model_info,
     terms = cleaned_terms,
+    at_list = at_values,
     original_terms = original_terms,
-    ci.lvl = ci.lvl
+    ci_level = ci_level,
+    margin = "marginalmeans",
+    latent = isTRUE(additional_dot_args$latent),
+    latent_thresholds = eff$thresholds
   )
 }
 
@@ -382,3 +364,112 @@ ggeffect <- function(model, terms, ci_level = 0.95, verbose = TRUE, ci.lvl = ci_
 
   tmp
 }
+
+
+.effect_prob_predictions <- function(eff, model, terms, ci_level, dof) {
+  eff.logits <- as.data.frame(eff$logit, stringsAsFactors = FALSE)
+  tmp <- cbind(eff$x, eff.logits)
+  ft <- (ncol(tmp) - ncol(eff.logits) + 1):ncol(tmp)
+  tmp <- .gather(
+    tmp,
+    names_to = "response.level",
+    values_to = "predicted",
+    colnames(tmp)[ft]
+  )
+
+  new_names <- c("x", "group", "facet", "panel", "grid")[seq_along(terms)]
+  colnames(tmp)[seq_along(terms)] <- new_names
+
+  if (!is.null(ci_level) && !is.na(ci_level)) {
+    ci <- 1 - ((1 - ci_level) / 2)
+  } else {
+    ci <- 0.975
+  }
+
+  # degrees of freedom
+  dof <- .get_df(model)
+  tcrit <- stats::qt(ci, df = dof)
+
+  # same for standard errors. we need to gather all data frames together,
+  # compute CI manually and then also fix column names.
+
+  eff.se.logits <- as.data.frame(eff$se.logit)
+  tmp2 <- .gather(
+    eff.se.logits,
+    names_to = "response.level",
+    values_to = "se",
+    colnames(eff.se.logits)
+  )
+  tmp2$conf.low <- tmp$predicted - tcrit * tmp2$se
+  tmp2$conf.high <- tmp$predicted + tcrit * tmp2$se
+  tmp2$std.error <- tmp2$se
+
+  tmp <- cbind(tmp, tmp2[, c("std.error", "conf.low", "conf.high")])
+  if (!inherits(model, "nestedLogit")) {
+    tmp$response.level <- substr(tmp$response.level, 7, max(nchar(tmp$response.level)))
+  }
+
+  # sort columns
+  valid_cols <- intersect(
+    c("x", "predicted", "std.error", "conf.low", "conf.high", "response.level", "group", "facet"),
+    colnames(tmp)
+  )
+
+  tmp[valid_cols]
+}
+
+
+.effect_latent_predictions <- function(eff, model, terms, ci_level, dof) {
+  tmp <- as.data.frame(eff)
+  # rename columns
+  colnames(tmp)[colnames(tmp) == "fit"] <- "predicted"
+  colnames(tmp)[colnames(tmp) == "se"] <- "std.error"
+
+  new_names <- c("x", "group", "facet", "panel", "grid")[seq_along(terms)]
+  for (i in seq_along(new_names)) {
+    colnames(tmp)[colnames(tmp) == terms[i]] <- new_names[i]
+  }
+
+  # remove CI
+  tmp$lower <- tmp$upper <- NULL
+
+  if (!is.null(ci_level) && !is.na(ci_level)) {
+    ci <- 1 - ((1 - ci_level) / 2)
+  } else {
+    ci <- 0.975
+  }
+
+  # degrees of freedom
+  dof <- .get_df(model)
+  tcrit <- stats::qt(ci, df = dof)
+  # CI
+  tmp$conf.low <- tmp$predicted - tcrit * tmp$std.error
+  tmp$conf.high <- tmp$predicted + tcrit * tmp$std.error
+
+  # sort columns
+  valid_cols <- intersect(
+    c(
+      "x", "predicted", "std.error", "conf.low", "conf.high",
+      "group", "facet", "panel", "grid"
+    ),
+    colnames(tmp)
+  )
+
+  tmp[valid_cols]
+}
+
+
+.validate_dot_arguments <- function(dot_args, not_allowed, fun) {
+  if (!.is_empty(dot_args)) {
+    not_allowed <- intersect(names(dot_args), not_allowed)
+    if (!.is_empty(not_allowed)) {
+      insight::format_alert(
+        sprintf(
+          "The following arguments are not supported by `%s` and will be ignored: %s\n",
+          fun,
+          toString(not_allowed)
+        )
+      )
+    }
+  }
+}
