@@ -20,18 +20,20 @@ test_that("validate ggpredict lmer against predict", {
 
 
 test_that("validate ggpredict lmer against marginaleffects", {
-  out1 <- marginaleffects::predictions(
+  out1 <- suppressWarnings(marginaleffects::predictions(
     fit,
     variables = "e42dep",
-    newdata = marginaleffects::datagrid(fit)
-  )
+    newdata = marginaleffects::datagrid(fit),
+    re.form = NULL
+  ))
   out1 <- out1[order(out1$e42dep), ]
   out2 <- ggpredict(
     fit,
     "e42dep",
     condition = c(grp = "child"),
     type = "random",
-    interval = "confidence"
+    interval = "confidence",
+    verbose = FALSE
   )
   expect_equal(
     out1$estimate,
@@ -52,16 +54,16 @@ test_that("ggpredict, lmer", {
   expect_s3_class(ggpredict(fit, "c12hour"), "data.frame")
   expect_s3_class(ggpredict(fit, c("c12hour", "c161sex")), "data.frame")
   expect_s3_class(ggpredict(fit, c("c12hour", "c161sex", "c172code")), "data.frame")
-  expect_s3_class(ggpredict(fit, "c12hour", type = "re"), "data.frame")
-  expect_s3_class(ggpredict(fit, c("c12hour", "c161sex"), type = "re"), "data.frame")
-  expect_s3_class(ggpredict(fit, c("c12hour", "c161sex", "c172code"), type = "re"), "data.frame")
+  expect_s3_class(ggpredict(fit, "c12hour", type = "random", verbose = FALSE), "data.frame")
+  expect_s3_class(ggpredict(fit, c("c12hour", "c161sex"), type = "random", verbose = FALSE), "data.frame") # nolint
+  expect_s3_class(ggpredict(fit, c("c12hour", "c161sex", "c172code"), type = "random", verbose = FALSE), "data.frame") # nolint
 })
 
 
 test_that("ggpredict, lmer", {
   pr <- ggpredict(fit, "c12hour")
   expect_equal(pr$std.error[1:5], c(0.2911, 0.2852, 0.2799, 0.2752, 0.2713), tolerance = 1e-3)
-  pr <- ggpredict(fit, c("c12hour", "c161sex", "c172code"), type = "re")
+  pr <- ggpredict(fit, c("c12hour", "c161sex", "c172code"), interval = "prediction")
   expect_equal(pr$std.error[1:5], c(3.5882, 3.58185, 3.58652, 3.58162, 3.57608), tolerance = 1e-3)
   # validate against predict
   pr <- ggpredict(fit, "c12hour")
@@ -80,7 +82,7 @@ test_that("ggpredict, lmer", {
     tolerance = 1e-3,
     ignore_attr = TRUE
   )
-  pr <- ggpredict(fit, "c12hour", type = "random")
+  pr <- ggpredict(fit, "c12hour", interval = "prediction")
   expect_equal(pr$conf.low[1:5], c(4.26939, 4.3036, 4.3377, 4.37168, 4.40554), tolerance = 1e-3)
 })
 
@@ -93,6 +95,7 @@ test_that("ggpredict, lmer-simulate", {
 
 
 test_that("ggeffect, lmer", {
+  skip_if_not_installed("effects")
   expect_s3_class(ggeffect(fit, "c12hour"), "data.frame")
   expect_s3_class(ggeffect(fit, c("c12hour", "c161sex")), "data.frame")
   expect_s3_class(ggeffect(fit, c("c12hour", "c161sex", "c172code")), "data.frame")
@@ -100,6 +103,7 @@ test_that("ggeffect, lmer", {
 
 
 test_that("ggeffect, lmer", {
+  skip_if_not_installed("emmeans")
   data(efc, package = "ggeffects")
   efc$cluster <- as.factor(efc$e15relat)
   efc <- datawizard::standardise(efc, c("c160age", "e42dep"), append = "_z")
@@ -114,6 +118,7 @@ test_that("ggeffect, lmer", {
 
 
 test_that("ggeffect, lmer", {
+  skip_if_not_installed("emmeans")
   data(efc, package = "ggeffects")
   efc$cluster <- as.factor(efc$e15relat)
   efc <- datawizard::to_factor(efc, c("e42dep", "c172code", "c161sex"))
@@ -135,6 +140,8 @@ test_that("ggeffect, lmer", {
 
 
 test_that("ggeffect, lmer", {
+  skip_if_not_installed("effects")
+  skip_if_not_installed("emmeans")
   data(sleepstudy, package = "lme4")
   m <- suppressWarnings(lme4::lmer(
     log(Reaction) ~ Days + I(Days^2) + (1 + Days + exp(Days) | Subject),
@@ -148,7 +155,7 @@ test_that("ggeffect, lmer", {
   expect_equal(p2$predicted[1], 253.5178, tolerance = 1e-3)
   expect_equal(p3$predicted[1], 5.535434, tolerance = 1e-3)
   expect_s3_class(
-    ggpredict(m, terms = c("Days", "Subject [sample=5]"), type = "re", verbose = FALSE),
+    ggpredict(m, terms = c("Days", "Subject [sample=5]"), type = "random", verbose = FALSE),
     "data.frame"
   )
 })
